@@ -1,4 +1,3 @@
-#' @importFrom insight link_inverse
 get_predictions_gamlss <- function(model, fitfram, ci.lvl, terms, model_class, value_adjustment, condition, ...) {
   se <- !is.null(ci.lvl) && !is.na(ci.lvl)
 
@@ -6,7 +5,7 @@ get_predictions_gamlss <- function(model, fitfram, ci.lvl, terms, model_class, v
   if (!is.null(ci.lvl) && !is.na(ci.lvl))
     ci <- (1 + ci.lvl) / 2
   else
-    ci <- .975
+    ci <- 0.975
 
   prdat <- suppressMessages(
     stats::predict(
@@ -43,7 +42,7 @@ get_predictions_gamlss <- function(model, fitfram, ci.lvl, terms, model_class, v
       condition = condition
     )
 
-  if (se && !is.null(se.pred)) {
+  if (se && .check_returned_se(se.pred)) {
 
     se.fit <- se.pred$se.fit
     fitfram <- se.pred$prediction_data
