@@ -4,7 +4,7 @@ get_predictions_multinom <- function(model, fitfram, ci.lvl, linv, value_adjustm
   if (!is.null(ci.lvl) && !is.na(ci.lvl))
     ci <- (1 + ci.lvl) / 2
   else
-    ci <- .975
+    ci <- 0.975
 
 
   prdat <-
@@ -16,13 +16,13 @@ get_predictions_multinom <- function(model, fitfram, ci.lvl, linv, value_adjustm
     )
 
   if (is.data.frame(prdat) || is.matrix(prdat))
-    nc <- 1:ncol(prdat)
+    nc <- seq_len(ncol(prdat))
   else
     nc <- 1
 
   # Matrix to vector
   tmp <- cbind(as.data.frame(prdat), fitfram)
-  fitfram <- .gather(tmp, key = "response.level", value = "predicted", colnames(tmp)[nc])
+  fitfram <- .gather(tmp, names_to = "response.level", values_to = "predicted", colnames(tmp)[nc])
 
 
   # se.pred <-
