@@ -1,8 +1,5 @@
 get_predictions_vglm <- function(model, fitfram, ci.lvl, linv, ...) {
-
-  if (!requireNamespace("VGAM", quietly = TRUE)) {
-    stop("Package `VGAM` needed to calculate adjusted predictions for a vector generalized linear model.", call. = FALSE)
-  }
+  insight::check_if_installed("VGAM", "to calculate adjusted predictions for a vector generalized linear model")
 
   se <- !is.null(ci.lvl) && !is.na(ci.lvl)
   mi <- insight::model_info(model)
@@ -11,7 +8,7 @@ get_predictions_vglm <- function(model, fitfram, ci.lvl, linv, ...) {
   if (!is.null(ci.lvl) && !is.na(ci.lvl))
     ci <- (1 + ci.lvl) / 2
   else
-    ci <- .975
+    ci <- 0.975
 
   if ((mi$is_ordinal || mi$is_multinomial) && !isTRUE(se)) {
     type <- "response"
