@@ -49,7 +49,7 @@ vcov.ggeffects <- function(object, vcov.fun = NULL, vcov.type = NULL, vcov.args
     return(NULL)
   }
 
-  model_frame <- insight::get_data(model)
+  model_frame <- insight::get_data(model, source = "frame")
 
   # check random effect terms. We can't compute SE if data has
   # factors with only one level, however, if user conditions on
