@@ -1,8 +1,8 @@
 if (suppressWarnings(
-  require("testthat") &&
-  require("ggeffects") &&
-  require("lme4") &&
-  require("sjlabelled")
+  requiet("testthat") &&
+  requiet("ggeffects") &&
+  requiet("lme4") &&
+  requiet("sjlabelled")
 )) {
   data(efc)
 
